@@ -1,4 +1,4 @@
-from django.core.management.base import BaseCommand
+from base.management import BaseCommand
 from django.core.management import call_command
 
 
