@@ -2,7 +2,7 @@ import shutil
 import os
 from subprocess import call
 
-from django.core.management.base import BaseCommand
+from base.management import BaseCommand
 from django.core.management import call_command
 from django.conf import settings
 
@@ -20,6 +20,7 @@ class Command(BaseCommand):
         )
 
     def handle(self, *args, **options):
+        self.stdout.write("Linting CSS code...")
         call_command("npm_install")
         shutil.os.chdir(settings.PROJECT_PATH)
         command_array = [
