@@ -1,5 +1,5 @@
-import {Dialog, addDropdownBox} from "../../common"
-import {tableResizeTemplate, tableInsertTemplate} from "./templates"
+import {Dialog, dropdownSelect} from "../../common"
+import {tableConfigurationTemplate, tableInsertTemplate} from "./templates"
 
 
 export class TableDialog {
@@ -44,15 +44,15 @@ export class TableDialog {
             text: gettext('Insert'),
             classes: 'fw-dark',
             click: () => {
-                const table = {type: 'table', content: []}
+                const table = {type: 'table', content: [{type: 'table_caption'}, {type: 'table_body', content: []}]}
+                const table_body = table.content[1]
 
                 for (let i = 0;i < rowCount;i++) {
                     const row = {type: 'table_row', content: []}
                     for (let j = 0;j < colCount;j++) {
                         row.content.push({type: 'table_cell', content: [{type: 'paragraph'}]})
                     }
-                    table.content.push(row)
-
+                    table_body.content.push(row)
                 }
                 const schema = this.editor.currentView.state.schema
                 this.editor.currentView.dispatch(
@@ -97,69 +97,51 @@ export class TableDialog {
     }
 }
 
-export class TableResizeDialog {
+export class TableConfigurationDialog {
     constructor(editor) {
         this.editor = editor
         this.dialogEl = false
         this.aligned = 'center'
         this.width = '100'
         this.layout = 'fixed'
+        this.category = 'none'
+        this.caption = false
     }
 
     init() {
         const {table} = this.findTable(this.editor.currentView.state)
-        if (table) {
-            this.width = table.attrs.width
-            this.aligned = table.attrs.aligned
-            this.layout = table.attrs.layout
-        }
-        this.insertDialog()
-    }
-
-    setTableAlignment() {
-        if (this.width == "100") {
-            this.dialog.dialogEl.querySelector("#table-alignment-btn").classList.add("disabled")
-            this.dialog.dialogEl.querySelector('#table-alignment-btn label').innerHTML = "Center"
+        if (!table) {
             return
         }
-        this.dialog.dialogEl.querySelector('#table-alignment-btn label').innerHTML =
-            document.getElementById(`table-alignment-${this.aligned}`).innerText
-    }
-
-    setTableWidth() {
-        if (this.width == "100") {
-            this.dialog.dialogEl.querySelector("#table-alignment-btn").classList.add("disabled")
-            this.dialog.dialogEl.querySelector('#table-alignment-btn label').innerHTML = "Center"
-        } else {
-            this.dialog.dialogEl.querySelector("#table-alignment-btn").classList.remove("disabled")
-        }
-        this.dialog.dialogEl.querySelector('#table-width-btn label').innerHTML =
-            document.getElementById(`table-width-${this.width}`).innerText
-    }
-
-    setTableLayout() {
-        this.dialog.dialogEl.querySelector('#table-layout-btn label').innerHTML =
-            document.getElementById(`table-layout-${this.layout}`).innerText
-        if (this.layout === "auto")
-            this.dialog.dialogEl.querySelector('#table-layout-btn').style.width = "105px"
-        else
-            this.dialog.dialogEl.querySelector('#table-layout-btn').style.width = "50px"
+        this.width = table.attrs.width
+        this.aligned = table.attrs.aligned
+        this.layout = table.attrs.layout
+        this.category = table.attrs.category
+        this.caption = table.attrs.caption
+        this.insertDialog()
     }
 
     findTable(state) {
         const $head = state.selection.$head
-        for (let d = $head.depth; d > 0; d--) if ($head.node(d).type.spec.tableRole == "table") {
-            return {table: $head.node(d), tablePos: $head.before(d)}}
-        return {table:false}
+        for (let d = $head.depth; d > 0; d--) {
+            if ($head.node(d).type.name == "table") {
+                return {table: $head.node(d), tablePos: $head.before(d)}
+            }
+        }
+        return {table: false}
     }
 
     submitForm() {
         const {table, tablePos} = this.findTable(this.editor.currentView.state)
-        if (!table) return
+        if (!table) {
+            return
+        }
         const attrs = Object.assign({}, table.attrs, {
-            width : this.width,
-            aligned : this.width === "100" ? "center" : this.aligned,
-            layout : this.layout
+            width: this.width,
+            aligned: this.width === "100" ? "center" : this.aligned,
+            layout: this.layout,
+            category: this.category,
+            caption: this.caption
         })
         this.editor.currentView.dispatch(this.editor.currentView.state.tr.setNodeMarkup(tablePos, false, attrs))
     }
@@ -179,60 +161,86 @@ export class TableResizeDialog {
         })
 
         this.dialog = new Dialog({
-            title: gettext('Resize table'),
-            body: tableResizeTemplate(),
-            width: 300,
-            height: 260,
+            title: gettext('Configure table'),
+            body: tableConfigurationTemplate({
+                language: this.editor.view.state.doc.firstChild.attrs.language
+            }),
+            width: 400,
+            height: 360,
             buttons,
             onClose: () => this.editor.currentView.focus()
         })
 
         this.dialog.open()
 
-        this.setTableAlignment()
-        this.setTableWidth()
-        this.setTableLayout()
-
-        addDropdownBox(
-            document.getElementById('table-alignment-btn'),
-            document.getElementById('table-alignment-pulldown')
+        const alignmentSelector = dropdownSelect(
+            this.dialog.dialogEl.querySelector('.table-alignment'),
+            {
+                onChange: newValue => {
+                    this.aligned = newValue
+                },
+                width: '80%',
+                value: this.aligned
+            }
         )
 
-        addDropdownBox(
-            document.getElementById('table-width-btn'),
-            document.getElementById('table-width-pulldown')
+        if (this.width == "100") {
+            alignmentSelector.setValue('center')
+            alignmentSelector.disable()
+            this.aligned = 'center'
+        }
+
+        dropdownSelect(
+            this.dialog.dialogEl.querySelector('.table-width'),
+            {
+                onChange: newValue => {
+                    this.width = newValue
+                    if (this.width == "100") {
+                        alignmentSelector.setValue('center')
+                        alignmentSelector.disable()
+                        this.aligned = 'center'
+                    } else {
+                        alignmentSelector.enable()
+                    }
+                },
+                width: '80%',
+                value: this.width
+            }
         )
 
-        addDropdownBox(
-            document.getElementById('table-layout-btn'),
-            document.getElementById('table-layout-pulldown')
+
+        dropdownSelect(
+            this.dialog.dialogEl.querySelector('.table-layout'),
+            {
+                onChange: newValue => {
+                    this.layout = newValue
+                },
+                width: '80%',
+                value: this.layout
+            }
         )
 
-        document.querySelectorAll('#table-alignment-pulldown li span').forEach(el => el.addEventListener(
-            'click',
-            event => {
-                event.preventDefault()
-                this.aligned = el.id.split('-')[2]
-                this.setTableAlignment()
+        dropdownSelect(
+            this.dialog.dialogEl.querySelector('.table-category'),
+            {
+                onChange: newValue => {
+                    this.category = newValue
+                },
+                width: '80%',
+                value: this.category
             }
-        ))
+        )
 
-        document.querySelectorAll('#table-width-pulldown li span').forEach(el => el.addEventListener(
-            'click',
-            event => {
-                event.preventDefault()
-                this.width = el.id.split('-')[2]
-                this.setTableWidth()
+        dropdownSelect(
+            this.dialog.dialogEl.querySelector('.table-caption'),
+            {
+                onChange: newValue => {
+                    this.caption = newValue === "true"
+                },
+                width: '80%',
+                value: String(this.caption)
             }
-        ))
+        )
 
-        document.querySelectorAll('#table-layout-pulldown li span').forEach(el => el.addEventListener(
-            'click',
-            event => {
-                event.preventDefault()
-                this.layout = el.id.split('-')[2]
-                this.setTableLayout()
-            }
-        ))
     }
 }
