@@ -1,4 +1,4 @@
-import {Dialog, escapeText} from "../../common"
+import {Dialog, escapeText, addAlert, get} from "../../common"
 import {SaveCopy} from "../../exporter/native"
 
 export class ModDocumentTemplate {
@@ -21,6 +21,15 @@ export class ModDocumentTemplate {
         if (this.editor.menu.headerView) {
             this.editor.menu.headerView.update()
         }
+        //Cache the template files using Service Worker
+        for (const key in styles.export_templates) {
+            const template = styles.export_templates[key]
+            get(template.template_file)
+        }
+        //Cache the required font related files too!
+        this.documentStyles.forEach(docStyle => {
+            docStyle.documentstylefile_set.forEach(([url, _filename]) => get(url))
+        })
     }
 
     addDocPartSettings() {
@@ -105,17 +114,23 @@ export class ModDocumentTemplate {
                             text: gettext('Copy'),
                             classes: "fw-dark",
                             click: () => {
-                                const copier = new SaveCopy(
-                                    editor.getDoc(),
-                                    editor.mod.db.bibDB,
-                                    editor.mod.db.imageDB,
-                                    editor.user,
-                                    selectTemplateDialog.dialogEl.querySelector('select').value
-                                )
-                                copier.init().then(({docInfo}) =>
-                                    editor.app.goTo(`/document/${docInfo.id}/`)
-                                ).catch(() => false)
-                                selectTemplateDialog.close()
+                                if (editor.app.isOffline()) {
+                                    addAlert('error', "You are offline. Please try again after you are online.")
+                                    selectTemplateDialog.close()
+                                } else {
+                                    const copier = new SaveCopy(
+                                        editor.getDoc(),
+                                        editor.mod.db.bibDB,
+                                        editor.mod.db.imageDB,
+                                        editor.user,
+                                        selectTemplateDialog.dialogEl.querySelector('select').value
+                                    )
+                                    copier.init().then(({docInfo}) =>
+                                        editor.app.goTo(`/document/${docInfo.id}/`)
+                                    ).catch(() => false)
+                                    selectTemplateDialog.close()
+                                }
+
                             }
                         },
                         {
@@ -124,7 +139,8 @@ export class ModDocumentTemplate {
                     ]
                 })
                 selectTemplateDialog.open()
-            }
+            },
+            disabled: editor => editor.app.isOffline()
         })
 
         fileMenu.content = fileMenu.content.sort((a, b) => a.order - b.order)
@@ -156,7 +172,8 @@ export class ModDocumentTemplate {
                             )
                             exporter.init()
                         })
-                    }
+                    },
+                    disabled: editor => editor.app.isOffline()
                 }
             } else {
                 return {
@@ -179,7 +196,8 @@ export class ModDocumentTemplate {
                             )
                             exporter.init()
                         })
-                    }
+                    },
+                    disabled: editor => editor.app.isOffline()
                 }
             }
         })
@@ -202,9 +220,8 @@ export class ModDocumentTemplate {
                         editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
                     )
                 },
-                selected: editor => {
-                    return editor.view.state.doc.firstChild.attrs.documentstyle === docStyle.slug
-                }
+                selected: editor => editor.view.state.doc.firstChild.attrs.documentstyle === docStyle.slug,
+                disabled: editor => editor.app.isOffline(),
             }
         })
     }
@@ -220,22 +237,24 @@ export class ModDocumentTemplate {
     addCitationStylesMenuEntries() {
         const settingsMenu = this.editor.menu.headerbarModel.content.find(menu => menu.id === 'settings'),
             citationStyleMenu = settingsMenu.content.find(menu => menu.id === 'citation_style')
-        citationStyleMenu.content = this.editor.view.state.doc.firstChild.attrs.citationstyles.map(citationstyle => {
-            return {
-                title: this.citationStyles[citationstyle],
-                type: 'setting',
-                action: editor => {
-                    const article = editor.view.state.doc.firstChild
-                    const attrs = Object.assign({}, article.attrs, {citationstyle})
-                    editor.view.dispatch(
-                        editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
-                    )
-                },
-                selected: editor => {
-                    return editor.view.state.doc.firstChild.attrs.citationstyle === citationstyle
+        if (citationStyleMenu) {
+            citationStyleMenu.content = this.editor.view.state.doc.firstChild.attrs.citationstyles.map(citationstyle => {
+                return {
+                    title: this.citationStyles[citationstyle],
+                    type: 'setting',
+                    action: editor => {
+                        const article = editor.view.state.doc.firstChild
+                        const attrs = Object.assign({}, article.attrs, {citationstyle})
+                        editor.view.dispatch(
+                            editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
+                        )
+                    },
+                    selected: editor => {
+                        return editor.view.state.doc.firstChild.attrs.citationstyle === citationstyle
+                    }
                 }
-            }
-        })
+            })
+        }
     }
 
 }
