@@ -5,4 +5,4 @@ export {tableMenuModel} from "./table"
 export {orderedListMenuModel} from "./ordered_list"
 export {imageMenuModel} from "./image"
 export {navigatorFilterModel} from "./navigator"
-export {figureMenuModel} from "./figure"
+export {figureMenuModel, figureWidthMenuModel} from "./figure"
