@@ -1,24 +1,44 @@
-import {addColumnAfter, addColumnBefore, deleteColumn, addRowBefore, addRowAfter, deleteRow, deleteTable,
+import {addColumnAfter, addColumnBefore, deleteColumn, addRowBefore, addRowAfter, deleteRow,
     mergeCells, splitCell, toggleHeaderRow, toggleHeaderColumn, toggleHeaderCell} from "prosemirror-tables"
-import {TableResizeDialog} from "../../dialogs"
+import {TableConfigurationDialog} from "../../dialogs"
 
 // from https://github.com/ProseMirror/prosemirror-tables/blob/master/src/util.js
 const findTable = function(state) {
     const $head = state.selection.$head
-    for (let d = $head.depth; d > 0; d--) if ($head.node(d).type.spec.tableRole == "table") return $head.node(d)
+    for (let d = $head.depth; d > 0; d--) {
+        if ($head.node(d).type.name == "table") {
+            return $head.node(d)
+        }
+    }
+    return false
+}
+
+// Adjusted from https://github.com/ProseMirror/prosemirror-tables/blob/master/src/commands.js
+export function deleteTable(state, dispatch) {
+    const $pos = state.selection.$anchor
+    for (let d = $pos.depth; d > 0; d--) {
+        const node = $pos.node(d)
+        if (node.type.name == "table") {
+            if (dispatch) {
+                dispatch(state.tr.delete($pos.before(d), $pos.after(d)).scrollIntoView())
+            }
+            return true
+        }
+    }
     return false
 }
 
 const tableAddedFromTemplate = function(state) {
     const $head = state.selection.$head
-    for (let d = $head.depth; d > 0; d--)
-        if ($head.node(d).type.spec.tableRole == "table") {
+    for (let d = $head.depth; d > 0; d--) {
+        if ($head.node(d).type.name == "table") {
             if ($head.node(d - 1).type.name === "table_part") {
                 return true
             } else {
                 return false
             }
         }
+    }
     return true
 }
 
@@ -308,12 +328,12 @@ export const tableMenuModel = () => ({
             order: 14,
         },
         {
-            title: gettext('Resize/Reposition'),
+            title: `${gettext('Configure')} ...`,
             type: 'action',
-            tooltip: gettext('Resize/Reposition a table.'),
+            tooltip: gettext('Configure the table.'),
             order: 15,
             action: editor => {
-                const dialog = new TableResizeDialog(editor)
+                const dialog = new TableConfigurationDialog(editor)
                 dialog.init()
                 return false
             },
