@@ -5,6 +5,7 @@ import {undo, redo, undoDepth, redoDepth} from "prosemirror-history"
 import {CitationDialog, FigureDialog, LinkDialog, MathDialog, TableDialog} from "../../dialogs"
 import {READ_ONLY_ROLES, COMMENT_ONLY_ROLES} from "../.."
 import {setBlockType} from "../../keymap"
+import {checkProtectedInSelection} from "../../state_plugins"
 
 const BLOCK_LABELS = {
     'paragraph': gettext('Normal Text'),
@@ -21,7 +22,11 @@ const BLOCK_LABELS = {
 // from https://github.com/ProseMirror/prosemirror-tables/blob/master/src/util.js
 const findTable = function(state) {
     const $head = state.selection.$head
-    for (let d = $head.depth; d > 0; d--) if ($head.node(d).type.spec.tableRole == "table") return $head.node(d)
+    for (let d = $head.depth; d > 0; d--) {
+        if ($head.node(d).type.spec.tableRole == "table") {
+            return $head.node(d)
+        }
+    }
     return false
 }
 
@@ -43,10 +48,12 @@ export function elementDisabled(editor, elementName) {
         // main editor
         const anchorDocPart = editor.currentView.state.selection.$anchor.node(2),
             headDocPart = editor.currentView.state.selection.$head.node(2)
+
         return !anchorDocPart ||
             headDocPart !== anchorDocPart ||
             !anchorDocPart.attrs.elements ||
-            !anchorDocPart.attrs.elements.includes(elementName)
+            !anchorDocPart.attrs.elements.includes(elementName) ||
+            checkProtectedInSelection(editor.view.state)
     } else {
         // footnote editor
         const anchorFootnote = editor.currentView.state.selection.$anchor.node(1),
@@ -81,7 +88,8 @@ function markDisabled(editor, markName) {
         return !anchorDocPart ||
             headDocPart !== anchorDocPart ||
             !anchorDocPart.attrs.marks ||
-            !anchorDocPart.attrs.marks.includes(markName)
+            !anchorDocPart.attrs.marks.includes(markName) ||
+            checkProtectedInSelection(editor.view.state)
     } else {
         // footnote editor
         const anchorFootnote = editor.currentView.state.selection.$anchor.node(1),
@@ -323,7 +331,7 @@ export const toolbarModel = () => ({
             selected: editor => {
                 const storedMarks = editor.currentView.state.storedMarks
                 if (
-                    storedMarks && storedMarks.some(mark => mark.type.name === 'strong') ||
+                    storedMarks?.some(mark => mark.type.name === 'strong') ||
                     editor.currentView.state.selection.$head.marks().some(mark => mark.type.name === 'strong')
                 ) {
                     return true
@@ -352,7 +360,7 @@ export const toolbarModel = () => ({
             selected: editor => {
                 const storedMarks = editor.currentView.state.storedMarks
                 if (
-                    storedMarks && storedMarks.some(mark => mark.type.name === 'em') ||
+                    storedMarks?.some(mark => mark.type.name === 'em') ||
                     editor.currentView.state.selection.$head.marks().some(mark => mark.type.name === 'em')
                 ) {
                     return true
@@ -386,7 +394,7 @@ export const toolbarModel = () => ({
             selected: editor => {
                 const storedMarks = editor.currentView.state.storedMarks
                 if (
-                    storedMarks && storedMarks.some(mark => mark.type.name === 'underline') ||
+                    storedMarks?.some(mark => mark.type.name === 'underline') ||
                     editor.currentView.state.selection.$head.marks().some(mark => mark.type.name === 'underline')
                 ) {
                     return true
