@@ -122,7 +122,7 @@ export class ModNavigator {
         const items = []
         let nearestHeader = ""
         this.editor.view.state.doc.descendants((node, pos) => {
-            if (node.attrs && node.attrs.hidden) {
+            if (node.attrs?.hidden) {
                 return false
             } else if (this.defaultFilters.includes(node.type.name) && node.textContent !== "") {
                 if (pos <= currentPos) {
