@@ -6,6 +6,8 @@ const key = new PluginKey('header')
 export const headerbarPlugin = function(options) {
     return new Plugin({
         key,
-        view(editorView) { return new HeaderbarView(editorView, options) }
+        view(editorView) {
+            return new HeaderbarView(editorView, options)
+        }
     })
 }
