@@ -52,12 +52,9 @@ const placeholderPlugin = function(nodeTitle) {
 }
 
 const pastePlugin = view => {
-
     const submitTags = tags => {
         const eState = view.state,
-            {decos} = key.getState(eState),
-            deco = decos.find()[0],
-            pos = deco.from,
+            pos = view.state.selection.from || view.state.doc.nodeSize - 1,
             nodes = tags.map(tag => eState.schema.nodes.tag.create({tag}))
         view.dispatch(
             view.state.tr.insert(pos, nodes)
@@ -120,7 +117,7 @@ const createTagInputEditor = (view, getPos, node) => {
             schema,
             doc: schema.nodeFromJSON({
                 type: 'doc',
-                content:[{
+                content: [{
                     type: 'tag',
                     content: []
                 }]
