@@ -6,6 +6,8 @@ const key = new PluginKey('toolbar')
 export const toolbarPlugin = function(options) {
     return new Plugin({
         key,
-        view(editorView) { return new ToolbarView(editorView, options) }
+        view(editorView) {
+            return new ToolbarView(editorView, options)
+        }
     })
 }
