@@ -3,15 +3,15 @@ import {DOMSerializer, DOMParser} from "prosemirror-model"
 import {FormatCitations} from "../../citations/format"
 import {fnSchema} from "../../schema/footnotes"
 import {cslBibSchema} from "../../bibliography/schema/csl_bib"
-import {descendantNodes} from "../tools/doc_contents"
+import {descendantNodes} from "../tools/doc_content"
 import {noSpaceTmp} from "../../common"
 
 export class DocxExporterCitations {
-    constructor(exporter, bibDB, csl, docContents, origCitInfos = []) {
+    constructor(exporter, bibDB, csl, docContent, origCitInfos = []) {
         this.exporter = exporter
         this.bibDB = bibDB
         this.csl = csl
-        this.docContents = docContents
+        this.docContent = docContent
         this.origCitInfos = origCitInfos
 
         this.citInfos = []
@@ -44,7 +44,7 @@ export class DocxExporterCitations {
             this.citInfos = this.citInfos.concat(this.origCitInfos)
         }
 
-        descendantNodes(this.docContents).forEach(
+        descendantNodes(this.docContent).forEach(
             node => {
                 if (node.type === 'citation') {
                     this.citInfos.push(JSON.parse(JSON.stringify(node.attrs)))
@@ -81,7 +81,7 @@ export class DocxExporterCitations {
         })
 
         // We create a standard body footnotecontainer node, add the citations into it, and parse it back.
-        const fnNode = fnSchema.nodeFromJSON({type:'footnotecontainer'})
+        const fnNode = fnSchema.nodeFromJSON({type: 'footnotecontainer'})
 
         const serializer = DOMSerializer.fromSchema(fnSchema)
         let dom = serializer.serializeNode(fnNode)
@@ -92,7 +92,7 @@ export class DocxExporterCitations {
         const cslBib = this.citFm.bibliography
         if (cslBib && cslBib[1].length > 0) {
             this.addReferenceStyle(cslBib[0])
-            const bibNode = cslBibSchema.nodeFromJSON({type:'cslbib'})
+            const bibNode = cslBibSchema.nodeFromJSON({type: 'cslbib'})
             const cslSerializer = DOMSerializer.fromSchema(cslBibSchema)
             dom = cslSerializer.serializeNode(bibNode)
             dom.innerHTML = cslBib[1].join('')
