@@ -102,6 +102,11 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
         body_input2 = self.driver2.find_element_by_class_name(
             'article-body'
         )
+        body_input.click()
+        body_input2.click()
+
+        body_input.click()
+        body_input2.click()
 
         for char in self.TEST_TEXT:
             body_input.send_keys(char)
@@ -172,6 +177,11 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
         body_input2 = self.driver2.find_element_by_class_name(
             'article-body'
         )
+        body_input.click()
+        body_input2.click()
+
+        body_input.click()
+        body_input2.click()
 
         p1 = multiprocessing.Process(
             target=self.input_text,
@@ -788,8 +798,16 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
         insert_button = WebDriverWait(driver, self.wait_time).until(
             EC.presence_of_element_located((By.CLASS_NAME, "insert-math"))
         )
+
         # type formula
-        math_field = driver.find_element_by_class_name('math-field')
+        math_field = WebDriverWait(driver, self.wait_time).until(
+            EC.visibility_of_element_located(
+                (
+                    By.CSS_SELECTOR,
+                    '.math-field'
+                )
+            )
+        )
         math_field.click()
 
         # wait for keyboard
@@ -1019,6 +1037,9 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
         self.driver2.find_element_by_css_selector(
             '.comment-answer .submit'
         ).click()
+        self.driver.find_element_by_css_selector(
+            '.margin-box.comment'
+        ).click()
         comment_answer = WebDriverWait(self.driver, self.wait_time).until(
             EC.presence_of_element_located(
                 (By.CSS_SELECTOR, ".comment-answer .comment-text-wrapper p")
@@ -1057,7 +1078,7 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
         ).click()
         WebDriverWait(self.driver, self.wait_time).until(
             EC.invisibility_of_element_located(
-                (By.CSS_SELECTOR, ".comment-answer")
+                (By.CSS_SELECTOR, ".comment-answer.collapse")
             )
         )
 
@@ -1080,15 +1101,16 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
     def add_figure(self, driver):
         button = driver.find_element_by_xpath('//*[@title="Figure"]')
         button.click()
-
-        caption = WebDriverWait(driver, self.wait_time).until(
-            EC.presence_of_element_located((By.CLASS_NAME, "caption"))
-        )
-
-        self.input_text(caption, "My figure")
-
+        time.sleep(1)
         # click on 'Insert image' button
-        driver.find_element_by_id('insert-figure-image').click()
+        WebDriverWait(driver, self.wait_time).until(
+            EC.presence_of_element_located(
+                (
+                    By.XPATH,
+                    '//*[normalize-space()="Insert image"]'
+                )
+            )
+        ).click()
 
         upload_button = WebDriverWait(driver, self.wait_time).until(
             EC.presence_of_element_located(
@@ -1135,6 +1157,14 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
         # click on 'Insert' button
         driver.find_element_by_css_selector("button.fw-dark").click()
 
+        caption = WebDriverWait(driver, self.wait_time).until(
+            EC.presence_of_element_located(
+                (By.CSS_SELECTOR, "div.article-body figure figcaption")
+            )
+        )
+        caption.click()
+        self.input_text(caption, "My figure")
+
     def get_image(self, driver):
         figure = driver.find_element_by_css_selector(
             'div.article-body figure'
@@ -1145,7 +1175,7 @@ class OneUserTwoBrowsersTests(LiveTornadoTestCase, EditorHelper):
 
     def get_caption(self, driver):
         caption = driver.find_element_by_css_selector(
-            'div.article-body figure figcaption span[data-caption]'
+            'div.article-body figure figcaption'
         )
 
         return caption.text
